# MDict MCP Server


Usage:

```
uvx mdict-mcp -d /path/to/mdicts/
```


[Available Tools](./TOOLS.md)


Dependencies: 
- mcp
- mdict-utils


Local testing:

```bash
uv --directory $HOME/Developer/mdict-mcp run mdict-mcp --log-level INFO --dictionary-dir /path/to/mdicts/
```
